#!/bin/sh
#
# mpwchange.sh, script per cambiare la master password 
# Copyright (C) 2006 Simone Piccardi
# by Simone Piccardi
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program or from the site that you downloaded it
# from; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA  02111-1307   USA
#

usage () {
    echo "Usage: mpwchange oldpass newpass"
    echo "       if you don't remember oldpass just look inside the file:"
    echo "       /etc/fuss-server/fuss-server.conf"
    echo "       for the MASTER_PASS variable definition"
}


##
## Defining used files, directories and program
##
CONF_FILE=/etc/fuss-server/fuss-server.conf
SERV_FUNC=/etc/fuss-server/service-functions
CONF_CMD=/usr/sbin/fuss-server-config
CA_DIR=/etc/fuss-server/Credentials
TEMPL_DIR=/usr/share/fuss-server/templates
SCRIPT_DIR=/usr/share/fuss-server/scripts

if [ "$#" -ne 2 ]; then
    usage
    exit 1
fi

if [ `id -u` != 0 ]; then 
    echo "You must be root to use this script"
fi

# Configuration variables
if [ -f "$CONF_FILE" ]; then
    . "$CONF_FILE"
else
    echo "Something wrong, missing configuration file $CONF_FILE"
    exit 1
fi

# Service functions, they must be present
if [ -f "$SERV_FUNC" ]; then
    . "$SERV_FUNC"
else
    echo "Something wrong, missing service functions file $SERV_FUNC"
    exit 1
fi

if [ "$MASTER_PASS" != "$1" ]; then
    echo "Wrong password!"
    exit 1
fi

# Setting other configuration variables
BASE=`echo $DOMAIN | 
       awk -F"." '{OFS=""; ORS=","; for (i=1; i <= NF; i++) print "dc=",$i}' | 
       sed -re 's/,$//g'`
USER="cn=admin,$BASE"

backfile $CONF_FILE
cp $CONF_FILE ${CONF_FILE}.new
sed -r "s/MASTER_PASS=\'$1\'/MASTER_PASS=\'$2\'/g" ${CONF_FILE}.new  \
    > $CONF_FILE 
rm ${CONF_FILE}.new

# Admin di LDAP
ldappasswd -x -h 127.0.0.1 -D "$USER" -w "$1" -a "$1" -s "$2" "$USER"
# per accesso di Samba a LDAP
smbpasswd -w "$2"
# accesso di smbldap a LDAP
SMBLDAPF=/etc/smbldap-tools/smbldap_bind.conf
backfile $SMBLDAPF
cp $SMBLDAPF ${SMBLDAPF}.new
cat ${SMBLDAPF}.new \
    | sed -r "s/$1/$2/g" \
    > $SMBLDAPF
rm -f ${SMBLDAPF}.new
# administrator del dominio
/usr/sbin/smbldap-passwd admin <<EOF
$2
$2
EOF

### OBSOLETA
## pwd per rootbinddn
#backfile /etc/ldap.secret
#backfile /etc/libnss-ldap.secret
#backfile /etc/pam_ldap.secret
#echo "$2" > /etc/libnss_ldap.secret
#echo "$2" > /etc/pam_ldap.secret
#echo "$2" > /etc/ldap.secret
#UMASK=`umask`
#umask 077

